# Changelog

## [0.1.5](https://github.com/cademirch/snakemake-logger-plugin-rich/compare/v0.1.4...v0.1.5) (2025-02-19)


### Bug Fixes

* ci ([2e0f93f](https://github.com/cademirch/snakemake-logger-plugin-rich/commit/2e0f93fa0c025ea16b19a00a6b550b60c4478174))

## [0.1.4](https://github.com/cademirch/snakemake-logger-plugin-rich/compare/v0.1.3...v0.1.4) (2025-02-19)


### Bug Fixes

* ci versions ([65f2cdd](https://github.com/cademirch/snakemake-logger-plugin-rich/commit/65f2cdd066849b3f6a333d6e56593f941859e14f))

## [0.1.3](https://github.com/cademirch/snakemake-logger-plugin-rich/compare/v0.1.2...v0.1.3) (2025-02-19)


### Bug Fixes

* fix release action ([a3c84f7](https://github.com/cademirch/snakemake-logger-plugin-rich/commit/a3c84f72ea3380d6cfd0ba89f9d628d939c189e8))

## [0.1.2](https://github.com/cademirch/snakemake-logger-plugin-rich/compare/0.1.1...v0.1.2) (2025-02-19)


### Bug Fixes

* :green_heart: add release-please ([8b3d39d](https://github.com/cademirch/snakemake-logger-plugin-rich/commit/8b3d39d8828daa4c9045622c06847e1cd13294e5))
* make work with newest interface ([c6f7377](https://github.com/cademirch/snakemake-logger-plugin-rich/commit/c6f73773636ee591bc750872c838deaeaeba62f6))

## [0.1.1] - 2024-11-03

- Added formatter and filter. 

## [0.1.0] - 2024-11-03

- Initial release.
